import React from 'react';
import { ColorVariant } from '../../hoc/withColor';
import Flex from '../flex';
import Input from '../input/Input';
import Select from '../select';
interface Translation {
    page?: string;
    pageSize?: string;
    goto?: string;
}
export interface PaginationProps {
    /** Total number of data items */
    total?: number;
    /** Current page number (default: 1) */
    page?: number;
    /** Number of data items per page (default = total) */
    pageSize?: number;
    /** Specify the sizeChanger options (default: [5, 10, 20, 50, 100]) */
    pageSizeOptions?: number[];
    /** FUTURE: Number of always visible pages at the beginning and end. (default: 1) */
    /** FUTURE: Number of always visible pages before and after the current page. (default: 1) */
    /** Determine whether to show pageSize select (default: true) */
    showSizeChanger?: boolean;
    /** Determine whether to show page previous button (default: true) */
    showPrevButton?: boolean;
    /** Determine whether to show page next button (default: true) */
    showNextButton?: boolean;
    /** Determine whether to show go to page button (default: false) */
    showGoToPage?: boolean;
    /** Determine whether you can jump to pages directly (default: false) */
    showQuickJumper?: boolean;
    /** Skip step (default: 5) */
    skipStep?: number;
    /** The variant to use. (default: outlined) */
    variant?: 'outlined' | 'contained' | 'text' | 'soft';
    /** The size of the avatar (default: medium) */
    size?: 'small' | 'medium' | 'large';
    /** The shape of avatar (default: circle) */
    shape?: 'square' | 'rounded' | 'circle';
    /** Disable pagination (default: false) */
    disabled?: boolean;
    /** To customize page item's innerHTML, -1 = dot range */
    renderPageItem?: (page: number, currentPage: number) => React.ReactNode;
    /** To customize previous button innerHTML, set false to hide */
    renderPrevBtn?: (currentPage: number) => React.ReactNode;
    /** To customize next button innerHTML, set false to hide */
    renderNextBtn?: (currentPage: number) => React.ReactNode;
    /** Called when the page number or pageSize is changed */
    onPageChange?: (page: number, pageSize: number) => any;
    /** Support translate language */
    translation?: Translation;
    /** Extend color from withColor */
    color?: ColorVariant;
    /** Customize */
    FlexWrapperOptions?: React.ComponentProps<typeof Flex>;
    SizeChangerSelectOptions?: React.ComponentProps<typeof Select>;
    GoToInputOptions?: React.ComponentProps<typeof Input>;
    className?: string;
    /** The ref is forwarded to the root element. */
    ref?: React.Ref<HTMLDivElement>;
}
export {};
