import * as React from 'react';
import Box from '../../box';
import '../sidebar.scss';
export interface SidebarMenuItem {
    /** img tag, JSX component, source string - recommend svg */
    icon?: React.ReactNode | string;
    label: React.ReactNode;
    /** open link if not empty, else trigger onItemClick */
    link?: string;
    subMenu?: Array<SidebarMenuItem>;
    itemProps?: React.ComponentProps<typeof Box>;
}
export interface SidebarItems {
    group?: string;
    isDivider?: boolean;
    menu: Array<SidebarMenuItem>;
}
export interface SidebarProps {
    /** Override css through class */
    className?: string;
    /** Home logo (img tag, JSX component, source string - recommend svg) */
    homeLogo?: React.ReactNode | string;
    /** Home title */
    homeTitle?: string;
    /** Home link (default: '/') */
    homeLink?: string;
    /** Menu and submenu */
    items: Array<SidebarItems>;
    /** Toggle small mode (default: false) */
    isSmall?: boolean;
    /** Auto toggle small mode when screen width <= small mode width 450px (default: true) */
    autoScale?: boolean;
    /** Sidebar width (default: 280px) */
    width?: number;
    /** Toggle sidebar (default: false) */
    hide?: boolean;
    /** Allow resize sidebar by drag mouse (default: false) */
    draggable?: boolean;
    /** hover to turn off small mode (default: true) */
    hoverToggle?: boolean;
    /** With backdrop - background overlay (default: false) */
    withBackdrop?: boolean;
    /** Animation duration by second (default 0.3s) */
    duration?: number;
    /** Show arrow icon in group */
    showGroupArrow?: boolean;
    /** Reference to sidebar */
    ref?: React.Ref<HTMLDivElement>;
    /** trigger event item click if link is empty */
    onItemClick?: (item: SidebarMenuItem) => void;
    /** trigger event on resize sidebar */
    onResize?: (width: number) => void;
    /** trigger event on click item has a link */
    onNavigate?: (link: string) => void;
    /** logic to active link */
    howActiveLink?: (link: string) => boolean;
}
export declare const Sidebar: React.ForwardRefExoticComponent<Pick<Pick<SidebarProps & import("../../../hoc").WithSxProps, "width" | "className" | "draggable" | "sx" | "hide" | "items" | "withBackdrop" | "onNavigate" | "duration" | "onItemClick" | "homeTitle" | "homeLogo" | "homeLink" | "howActiveLink" | "isSmall" | "autoScale" | "hoverToggle" | "showGroupArrow" | "onResize"> & React.RefAttributes<unknown> & import("../../../hoc").WithResponsiveProps<Pick<SidebarProps & import("../../../hoc").WithSxProps, "width" | "className" | "draggable" | "sx" | "hide" | "items" | "withBackdrop" | "onNavigate" | "duration" | "onItemClick" | "homeTitle" | "homeLogo" | "homeLink" | "howActiveLink" | "isSmall" | "autoScale" | "hoverToggle" | "showGroupArrow" | "onResize"> & React.RefAttributes<unknown>>, "sm" | "md" | "lg" | "xl" | "width" | "className" | "draggable" | "key" | "sx" | "hide" | "items" | "withBackdrop" | "onNavigate" | "duration" | "onItemClick" | "homeTitle" | "homeLogo" | "homeLink" | "howActiveLink" | "isSmall" | "autoScale" | "hoverToggle" | "showGroupArrow" | "onResize"> & React.RefAttributes<unknown>>;
export default Sidebar;
